@@ -1,11 +1,13 @@
 package WordList::EN::CountryNames;
 
-our $DATE = '2016-01-12'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2016-01-13'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 use WordList;
 our @ISA = qw(WordList);
 
+our %STATS = ("num_words",249,"num_words_contains_unicode",0,"longest_word_len",36,"shortest_word_len",2,"avg_word_len",10.0923694779116,"num_words_contains_whitespace",72,"num_words_contains_nonword_chars",74); # STATS
+
 1;
 # ABSTRACT: English country names
 
@@ -22,7 +24,7 @@ WordList::EN::CountryNames - English country names
 
 =head1 VERSION
 
-This document describes version 0.03 of WordList::EN::CountryNames (from Perl distribution WordList-EN-CountryNames), released on 2016-01-12.
+This document describes version 0.04 of WordList::EN::CountryNames (from Perl distribution WordList-EN-CountryNames), released on 2016-01-13.
 
 =head1 SYNOPSIS
 
@@ -43,6 +45,20 @@ This document describes version 0.03 of WordList::EN::CountryNames (from Perl di
  # Get all the words
  my @all_words = $wl->all_words;
 
+=head1 STATISTICS
+
+ +----------------------------------+------------------+
+ | key                              | value            |
+ +----------------------------------+------------------+
+ | avg_word_len                     | 10.0923694779116 |
+ | longest_word_len                 | 36               |
+ | num_words                        | 249              |
+ | num_words_contains_nonword_chars | 74               |
+ | num_words_contains_unicode       | 0                |
+ | num_words_contains_whitespace    | 72               |
+ | shortest_word_len                | 2                |
+ +----------------------------------+------------------+
+
 =head1 SEE ALSO
 
 Converted from L<Games::Word::Wordlist::Country> 0.02.
